# spotii-notification-client
API for send SMS/Email messages

- API version: v1.0
- Package version: 1.0.0

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install spotii-notification-client
```

Then import the package:
```python
import spotii_notification_client 
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import spotii_notification_client
from spotii_notification_client.rest import ApiException
from pprint import pprint

# create an instance of the API class
api_instance = spotii_notification_client.EmailApi(spotii_notification_client.ApiClient(configuration))
body = spotii_notification_client.EmailMessage() # EmailMessage | 

try:
    api_response = api_instance.email_messages_create(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling EmailApi->email_messages_create: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8000/api/v1.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*EmailApi* | [**email_messages_create**](docs/EmailApi.md#email_messages_create) | **POST** /email/messages/ | 
*SmsApi* | [**sms_messages_create**](docs/SmsApi.md#sms_messages_create) | **POST** /sms/messages/ | 

## Documentation For Models

 - [EmailMessage](docs/EmailMessage.md)
 - [SMSMessage](docs/SMSMessage.md)

## Documentation For Authorization

 All endpoints do not require authorization.


## Author

Nuclearo DMCC https://www.nuclearo.com/
